#!/bin/sh

ETC_VSERVERS=/etc/vservers
vserver_mknod()
{
	mknod $1 $2 $3 $4
	chmod $5 $1
}

if [ $# != 2 ] ; then
	echo install-pre.sh vserver vroot
else
	VROOT=$2
	mkdir -p $ETC_VSERVERS
	mkdir -p $VROOT 2>/dev/null
	rm -fr $VROOT/dev
	mkdir -p $VROOT/dev && chmod 755 $VROOT/dev
	mkdir $VROOT/dev/pts
	vserver_mknod $VROOT/dev/null c 1 3 666
	vserver_mknod $VROOT/dev/zero c 1 5 666
	vserver_mknod $VROOT/dev/full c 1 7 666
	vserver_mknod $VROOT/dev/random c 1 8 644
	vserver_mknod $VROOT/dev/urandom c 1 9 644
	vserver_mknod $VROOT/dev/tty c 5 0 666
	vserver_mknod $VROOT/dev/ptmx c 5 2 666
	# We fake this device to help some package managers
	touch $VROOT/dev/hdv1
fi

